/*

Ripley v1.1
Simple CSS animation via JavaScript.
https://github.com/adamwjohnson5/ripley
By Adam Johnson
MIT License 2019

Usage:

Vanilla JS:
let rply = new Ripley(elem);
rply.animate(prop, val, {speed: 0, ease: '', delay: 0});

jQuery:
$(elem).ripley({prop, val, {speed: 0, ease: '', delay: 0}});

*/
"use strict";

/* ES6 */

class Ripley {

    constructor(elem) {
        this.elem = elem;
    }
    
    animate(prop, val, options) {
        // Check for optional params
        if (! options) {
            options = {};
        }
        // Defaults
        if (! options.speed) {
            options.speed = 0.25;
        }
        if (! options.ease) {
            options.ease = 'ease-out';
        }
        if (! options.delay) {
            options.delay = 0;
        }
        const object = this.elem;
        window.setTimeout(function() { // Hack incase display property changed
            let i = prop.replace(/([A-Z])/g, '-$1').toLowerCase(); // Convert property to slug-case
            object.style.transition = i + ' ' + options.speed + 's ' + options.ease + ' ' + options.delay + 's';
            object.style[prop] = val;
            // Clear transition on finish
            object.addEventListener('transitionend', function() {
                object.style.transition = '';
            });
        }, 100);
    }
    
}

/* jQuery */

if (typeof jQuery !== 'undefined') {
    (function($) {
        $.fn.ripley = function(prop, val, options) {
            var settings = $.extend({}, $.fn.ripley.defaults, options);
            // Loop if multiple elements and support chaining
            return this.each(function() {
                const object = $(this);
                window.setTimeout(function() { // Hack incase display property changed
                    let i = prop.replace(/([A-Z])/g, '-$1').toLowerCase(); // Convert property to slug-case
                    object.css({
                        transition: i + ' ' + settings.speed + 's ' + settings.ease + ' ' + settings.delay + 's'
                    });
                    object.css({
                        [prop]: val
                    });
                    // Clear transition on finish
                    object.bind('transitionend', function() {
                        object.css({
                            transition: ''
                        });
                    });
                }, 100);
            });
        };
        // Default options
        $.fn.ripley.defaults = {
            speed: 0.25,
            ease: 'ease-out',
            delay: 0
        }
    })(jQuery);
}